.. _options:

#######################
FitBenchmarking Options
#######################

The default behaviour of FitBenchmarking can be changed by
supplying an options file.  The default values of these options,
and how to override them, are given in the pages below.

.. toctree::
    :titlesonly:
    :maxdepth: 2
    :caption: Contents:

    fitting_option
    minimizer_option
    plotting_option
    logging_option


The options file must be a ``.ini`` formatted file
(`see here <https://docs.python.org/3/library/configparser.html#supported-ini-file-structure>`__).
Some example files can be found in the ``examples`` folder of the source, which is also
available to download at :ref:`BenchmarkProblems`.


